## Microsoft Bing Web Search SDK for Python

This is the Microsoft Bing Web Search Client Library.

This package has been tested with Python 2.7, 3.5, 3.6, 3.7 and 3.8.


## Usage

For more, see [Web Search](https://docs.microsoft.com/en-us/bing/search-apis/bing-web-search/overview)
on docs.microsoft.com.

## Provide Feedback

If you encounter any bugs or have suggestions, please file an issue in
the [Issues](https://github.com/microsoft/bing-search-sdk-for-python/issues)
section of the project.

